==> v10.0.1.tar.gz: bookmarks/l10n/fr.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Favoris",
    "You bookmarked \"%s\"" : "Vous avez mis en favori \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s à mis en favori \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Quelqu'un a mis en favori \"%s\"",
    "You deleted \"%s\"" : "Vous avez supprimé \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s a supprimé \"%2$s\"",
    "Someone deleted \"%s\"" : "Quelqu'un à supprimé \"%s\"",
    "You created folder \"%s\"" : "Vous avez créé le dossier \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s à créé le dossier \"%2$s\"",
    "Someone created folder \"%s\"" : "Quelqu'un à créé le dossier \"%s\"",
    "You moved folder \"%s\"" : "Vous avez déplacé le dossier \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s à déplacé le dossier \"%2$s\"",
    "Someone moved folder \"%s\"" : "Quelqu'un à déplacé le dossier \"%s\"",
    "You deleted folder \"%s\"" : "Vous avez supprimé le dossier \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s à supprimé le dossier %2$s",
    "Someone deleted folder \"%s\"" : "Quelqu'un à supprimé le dossier \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Vous avez partagé le dossier \"%1$s\" avec \"%2$s\"",
    "You shared folder \"%s\" with someone" : "Vous avez partagé le dossier \"%s\" avec quelqu'un",
    "%1$s shared folder \"%2$s\" with you" : "%1$s a partagé le dossier \"%2$s\" avec vous",
    "Someone shared folder \"%s\" with you" : "Quelqu'un à partagé le dossier \"%s\" avec vous",
    "You unshared folder \"%1$s\" with %2$s" : "Vous avez annulé le partage du dossier \"%1$s\" avec %2$s",
    "You unshared folder \"%s\" with someone" : "Vous avez annulé le partage du dossier \"%s\" avec quelqu'un",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s a annulé le partage du dossier \"%2$s\" avec vous",
    "Someone unshared folder \"%s\" with you" : "Quelqu'un a annulé le partage du dossier \"%s\" avec vous",
    "No file provided for import" : "Aucun fichier à importer.",
    "Unsupported file type for import" : "Type de fichier non pris en charge",
    "Bookmarks shared by %s" : "Favoris partagés par %s",
    "Frequent bookmarks" : "Favoris fréquents",
    "Recent bookmarks" : "Favoris récents",
    "Bookmark" : "Favori",
    "Bookmark deleted" : "Favori supprimé",
    "Bookmark created" : "Favori créé",
    "Bookmark moved" : "Favori déplacé",
    "Bookmark updated" : "Favori mis à jour",
    "Create bookmark" : "Créer un favori",
    "Takes a link and adds it to your collection of bookmarks." : "Prenez un lien et ajoutez-le à votre collection de favoris.",
    "A Bookmark manager for Nextcloud" : "Un gestionnaire de favoris pour Nextcloud",
    "Enter new title" : "Saisissez un nouveau titre",
    "Select bookmark" : "Sélectionner le favori",
    "Details" : "Propriétés",
    "Rename" : "Renommer",
    "Move" : "Déplacer",
    "Delete" : "Supprimer",
    "Do you really want to delete this bookmark?" : "Voulez-vous vraiment supprimer ce signet?",
    "Content pending" : "Contenu en attente",
    "This content is being downloaded for offline use. Please check back later." : "Ce contenu est en cours de téléchargement pour une utilisation hors-ligne. Merci de revenir plus tard.",
    "Open all selected" : "Ouvrir toute la sélection",
    "Move selection" : "Déplacer la sélection",
    "Edit tags of selection" : "Modifier les étiquettes de la sélection",
    "Delete selection" : "Supprimer la sélection",
    "Select all" : "Tout sélectionner",
    "Cancel selection" : "Annuler la sélection",
    "Selected {folders} folders and {bookmarks} bookmarks" : "{folders} dossiers et {bookmarks} marque-pages sélectionnés",
    "Do you really want to delete these items?" : "Voulez-vous vraiment supprimer ces éléments?",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n favori sélectionné","%n favoris sélectionnés"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n  dossier sélectionné","%n dossiers sélectionnés"],
    "Go back" : "Revenir en arrière",
    "Share folder" : "Partager ce dossier",
    "Select one or more tags" : "Sélectionnez une ou plusieurs étiquettes",
    "New" : "Créer",
    "New bookmark" : "Nouveau favori",
    "New folder" : "Nouveau dossier",
    "Change to grid view" : "Passer à la vue en grille",
    "Change to list view" : "Passer à la vue en liste",
    "Copy RSS Feed of current view" : "Copier le flux RSS de la vue actuelle",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Le flux RSS nécessite une authentification avec vos identifiants Nextcloud",
    "Sort by created date" : "Trié par date de création",
    "Sort by last modified" : "Trier par dernière modification",
    "Sort by title" : "Trier par titre",
    "Sort by click count" : "Trier par nombre de cliques",
    "Sort by manual order" : "Trier manuellement",
    "RSS feed copied" : "Flux RSS copié",
    "Enter a link" : "Saisissez un lien",
    "Enter a title" : "Saisissez un titre",
    "No bookmarks found" : "Aucun favori",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} dossiers et {bookmarks} favoris",
    "_%n bookmark_::_%n bookmarks_" : ["%n favori","%n favoris"],
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
    "Select folder" : "Sélectionner un dossier",
    "Enter folder title" : "Saisissez le nom du dossier",
    "Shared by {user}" : "Partagé par l'{user}",
    "Rename folder" : "Renommer le dossier",
    "Move folder" : "Déplacer le dossier",
    "Delete folder" : "Supprimer le dossier",
    "Do you really want to delete this folder?" : "Voulez-vous vraiment supprimer ce dossier?",
    "Choose folder" : "Choisir le dossier",
    "Submit" : "Envoyer",
    "Cancel" : "Annuler",
    "Deleting bookmarks" : "Suppression des favoris",
    "Deleting selection" : "Suppression de la sélection",
    "Importing bookmarks" : "Import des favoris",
    "Moving selection" : "Déplacement de la sélection",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Déplacement de %n dossier et de certains signets","Déplacement de %n dossiers et de certains signets"],
    "_Moving %n folder_::_Moving %n folders_" : ["Déplacement de %n dossier","Déplacement de %n dossiers"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Déplacement de %n favori","Déplacement de %n favoris"],
    "All bookmarks" : "Tous les favoris",
    "Recent" : "Récent",
    "Files" : "Fichiers",
    "Broken links" : "Liens brisés",
    "New tag" : "Nouvelle étiquette",
    "Search tags" : "Rechercher des étiquettes",
    "Untagged" : "Sans étiquette",
    "{used} bookmarks of {available} available" : "{used} favoris sur {available} disponibles",
    "No bookmarked files" : "Aucun fichier en favori",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les favoris vers des fichiers comme des photos ou des PDF seront automatiquement enregistrés dans vos fichiers Nextcloud, pour que vous puissiez y accéder même quand le lien est hors connexion.",
    "No bookmarks here" : "Aucun favori ici",
    "Start by importing bookmarks from a file or synchronizing your browser bookmarks with this app" : "Commencez en important des favoris depuis un fichier ou en synchronisant ceux de votre navigateur avec cette application.",
    "Import bookmarks" : "Importer des favoris",
    "Sync with your browser" : "Synchronisez avec votre navigateur",
    "Import" : "Importer",
    "Export" : "Exporter",
    "Archive path" : "Archiver le chemin d'accès",
    "Enter the path of a folder where bookmarked files should be stored" : "Indiquez un dossier où enregistrer le fichier des favoris",
    "Client apps" : "Applications clientes",
    "Also check out the collection of client apps that integrate with this app: " : "Découvrez également une gamme d'applications client qui s'intègrent à cette application : ",
    "Install web app on device" : "Installer l’application web sur l’appareil",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Vous pouvez installer cette application sur l’écran d’accueil de votre téléphone pour accéder rapidement à vos favoris. Vous pourrez facilement retirer cette application de votre écran si elle ne vous plaît pas.",
    "Install on home screen" : "Installer sur l'écran d'accueil",
    "Bookmarklet" : "Favelets",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Faites-le glisser dans les signets de votre navigateur et cliquez dessus pour ajouter rapidement une page Web à vos signets.",
    "Add to {instanceName}" : "Ajouter à {instanceName}",
    "Clear data" : "Effacer les données",
    "Permanently remove all bookmarks from your account." : "Supprimer de manière définitive tous les favoris de votre compte.",
    "Delete all bookmarks" : "Supprimer tous les favoris",
    "Do you really want to delete all your bookmarks?" : "Voulez-vous réellement supprimer tous vos favoris ?",
    "Please select \"Add to home screen\" in your browser menu" : "Veuillez sélectionner \"Ajouter à l'écran d'accueil\" dans le menu de votre navigateur",
    "Title" : "Titre",
    "Link" : "Lien",
    "Tags" : "Étiquettes",
    "Select tags and create new ones" : "Sélectionner des étiquettes ou en créer de nouvelles",
    "Notes" : "Notes",
    "Notes for this bookmark …" : "Notes pour ce favori ...",
    "Archived file" : "Fichier archivé",
    "Open file" : "Ouvrir le fichier",
    "Open file location" : "Ouvrir l’emplacement du fichier",
    "Created {time} ago" : "Créé il y a {time}",
    "Created on {date}" : "Créé le {date}",
    "Owner" : "Propriétaire",
    "Sharing" : "Partagé",
    "Select a user or group" : "Sélectionnez un utilisateur ou un groupe",
    "Share link" : "Lien de partage",
    "Reading allowed" : "Lecture autorisée",
    "Copy link" : "Copier le lien",
    "Copy RSS feed" : "Copier le flux RSS",
    "Delete link" : "Supprimer le lien",
    "Create public link" : "Créer une lien de partage public",
    "Resharing allowed" : "Repartage autorisé",
    "Editing allowed" : "Modification autorisée",
    "Allow editing" : "Autoriser la modification",
    "Allow resharing" : "Autoriser le repartage",
    "Remove share" : "Supprimer le partage",
    "Link copied" : "Lien copié",
    "Privacy" : "Vie privée",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bookmarks tentera d'accéder aux pages Web que vous enregistrez pour ajouter automatiquement des informations à leur sujet.",
    "Enable accessing and collecting information from the web pages you add" : "Activer l'accès et la collecte d'informations à partir des pages Web que vous enregistrez",
    "Performance" : "Performance",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Dans une installation avec un grand nombre d'utilisateurs, il peut être utile de restreindre le nombre de favoris par compte.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nombre maximum de signets autorisés par compte (0 pour aucune limite ; par défaut, aucune limite)",
    "Previews" : "Prévisualisations",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Afin d'afficher de vrais captures d'écrans de vos sites favoris, Favoris peut utiliser des services tiers pour générer ces aperçus",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Vous pouvez vous inscrire gratuitement sur screeenly.com ou configurer votre propre serveur.",
    "Screeenly API URL" : "URL API Screenly",
    "Screeenly API key" : "Clé API Screenly",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL de l'API Webshot",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Clé API de ScreenshotMachine",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the pageres cli on your server and bookmarks will find it." : "Installez simplement le client pageres sur votre serveur et l'application Bookmarks le trouvera",
    "Failed to load settings" : "Echec du chargement des paramètres",
    "Failed to save settings" : "Echec de la sauvegarde des paramètres",
    "Add a bookmark" : "Ajouter un favori",
    "This URL is already bookmarked! Overwrite?" : "Cette URL est déjà dans les favoris ! Remplacer ?",
    "Enter bookmark title" : "Saisissez le nom du favori",
    "Enter bookmark URL" : "Saisissez l'url du favori",
    "Folder" : "Dossier",
    "Root Folder" : "Dossier racine",
    "Save" : "Enregistrer",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "L’accès au réseau est désactivé par défaut. Rendez-vous dans les paramètres administrateur de cette application pour autoriser le téléchargement de prévisualisations et de favicons.",
    "Failed to count unavailable bookmarks" : "Impossible de compter les favoris indisponibles",
    "Failed to count archived bookmarks" : "Impossible de compter les favoris archivés",
    "Failed to load bookmark" : "Impossible de charger les favoris",
    "Failed to find existing bookmark" : "Impossible de trouver un signet existant",
    "Failed to create bookmark" : "Echec de la création du favori",
    "Failed to save bookmark" : "Echec de la sauvegarde du favori",
    "Failed to move bookmark" : "Impossible de déplacer le favori",
    "Failed to delete bookmark" : "Impossible de supprimer le favori",
    "Failed to rename tag" : "Impossible de renommer le tag",
    "Failed to load tags" : "Impossible de charger les étiquettes",
    "Failed to load folders" : "Impossible de charger les dossiers",
    "Failed to delete folder" : "Impossible de supprimer le dossier",
    "Failed to create folder" : "Impossible de créer le dossier",
    "Failed to fetch bookmarks." : "Impossible de récupérer les signets.",
    "Failed to change setting" : "Impossible de modifier les paramètres",
    "Failed to load setting {key}" : "Échec du chargement du paramètre {key}",
    "Failed to update share {shareId}" : "Impossible de mettre à jour le partage {shareId}",
    "Failed to delete share {shareId}" : "Impossible de supprimer le partage {shareId}",
    "Bookmarks feed" : "Flux de suivi"
},
"nplurals=2; plural=(n > 1);");

==> v10.4.0.tar.gz: bookmarks/l10n/fr.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Favoris",
    "You bookmarked \"%s\"" : "Vous avez mis en favori \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s à mis en favori \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Quelqu'un a mis en favori \"%s\"",
    "You deleted \"%s\"" : "Vous avez supprimé \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s a supprimé \"%2$s\"",
    "Someone deleted \"%s\"" : "Quelqu'un à supprimé \"%s\"",
    "You created folder \"%s\"" : "Vous avez créé le dossier \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s à créé le dossier \"%2$s\"",
    "Someone created folder \"%s\"" : "Quelqu'un à créé le dossier \"%s\"",
    "You moved folder \"%s\"" : "Vous avez déplacé le dossier \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s à déplacé le dossier \"%2$s\"",
    "Someone moved folder \"%s\"" : "Quelqu'un à déplacé le dossier \"%s\"",
    "You deleted folder \"%s\"" : "Vous avez supprimé le dossier \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s à supprimé le dossier %2$s",
    "Someone deleted folder \"%s\"" : "Quelqu'un à supprimé le dossier \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Vous avez partagé le dossier \"%1$s\" avec \"%2$s\"",
    "You shared folder \"%s\" with someone" : "Vous avez partagé le dossier \"%s\" avec quelqu'un",
    "%1$s shared folder \"%2$s\" with you" : "%1$s a partagé le dossier \"%2$s\" avec vous",
    "Someone shared folder \"%s\" with you" : "Quelqu'un à partagé le dossier \"%s\" avec vous",
    "You unshared folder \"%1$s\" with %2$s" : "Vous avez annulé le partage du dossier \"%1$s\" avec %2$s",
    "You unshared folder \"%s\" with someone" : "Vous avez annulé le partage du dossier \"%s\" avec quelqu'un",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s a annulé le partage du dossier \"%2$s\" avec vous",
    "Someone unshared folder \"%s\" with you" : "Quelqu'un a annulé le partage du dossier \"%s\" avec vous",
    "No file provided for import" : "Aucun fichier à importer.",
    "Unsupported file type for import" : "Type de fichier non pris en charge",
    "Bookmarks Backups" : "Sauvegarde de favoris",
    "Bookmarks shared by %s" : "Favoris partagés par %s",
    "Frequent bookmarks" : "Favoris fréquents",
    "Recent bookmarks" : "Favoris récents",
    "Bookmark" : "Favori",
    "Bookmark deleted" : "Favori supprimé",
    "Bookmark created" : "Favori créé",
    "Bookmark moved" : "Favori déplacé",
    "Bookmark updated" : "Favori mis à jour",
    "Create bookmark" : "Créer un favori",
    "Takes a link and adds it to your collection of bookmarks." : "Prenez un lien et ajoutez-le à votre collection de favoris.",
    "A Bookmark manager for Nextcloud" : "Un gestionnaire de favoris pour Nextcloud",
    "Enter new title" : "Saisissez un nouveau titre",
    "Select bookmark" : "Sélectionner le favori",
    "Details" : "Propriétés",
    "Rename" : "Renommer",
    "Move" : "Déplacer",
    "Add to folders" : "Ajouter aux dossiers",
    "Delete" : "Supprimer",
    "Do you really want to delete this bookmark?" : "Voulez-vous vraiment supprimer ce signet?",
    "Content pending" : "Contenu en attente",
    "This content is being downloaded for offline use. Please check back later." : "Ce contenu est en cours de téléchargement pour une utilisation hors-ligne. Merci de revenir plus tard.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les favoris vers des fichiers comme des photos ou des PDF seront automatiquement enregistrés dans vos fichiers Nextcloud, de sorte que vous puissiez toujours les trouver même lorsque le lien est hors ligne.",
    "Open all selected" : "Ouvrir toute la sélection",
    "Move selection" : "Déplacer la sélection",
    "Edit tags of selection" : "Modifier les étiquettes de la sélection",
    "Delete selection" : "Supprimer la sélection",
    "Select all" : "Tout sélectionner",
    "Cancel selection" : "Annuler la sélection",
    "Selected {folders} folders and {bookmarks} bookmarks" : "{folders} dossiers et {bookmarks} marque-pages sélectionnés",
    "Do you really want to delete these items?" : "Voulez-vous vraiment supprimer ces éléments?",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n favori sélectionné","%n favoris sélectionnés","%n favoris sélectionnés"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n  dossier sélectionné","%n dossiers sélectionnés","%n dossiers sélectionnés"],
    "Go back" : "Revenir en arrière",
    "Share folder" : "Partager ce dossier",
    "Select one or more tags" : "Sélectionnez une ou plusieurs étiquettes",
    "New" : "Créer",
    "New bookmark" : "Nouveau favori",
    "New folder" : "Nouveau dossier",
    "Change to grid view" : "Passer à la vue en grille",
    "Change to list view" : "Passer à la vue en liste",
    "Copy RSS Feed of current view" : "Copier le flux RSS de la vue actuelle",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Le flux RSS nécessite une authentification avec vos identifiants Nextcloud",
    "Sort by created date" : "Trié par date de création",
    "Sort by last modified" : "Trier par dernière modification",
    "Sort by title" : "Trier par titre",
    "Sort by click count" : "Trier par nombre de cliques",
    "Sort by manual order" : "Trier manuellement",
    "RSS feed copied" : "Flux RSS copié",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Ajout de %n favori au nouveau dossier","Ajout de %n favoris au nouveau dossier","Ajout de %n favoris au nouveau dossier"],
    "Enter a link" : "Saisissez un lien",
    "Enter a title" : "Saisissez un titre",
    "No bookmarks found" : "Aucun favori",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} dossiers et {bookmarks} favoris",
    "_%n bookmark_::_%n bookmarks_" : ["%n favori","%n favoris","%n favoris"],
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers","%n dossiers"],
    "Welcome to Bookmarks" : "Bienvenu dans les favoris",
    "Add a bookmark" : "Ajouter un favori",
    "Import bookmarks" : "Importer des favoris",
    "Sync with your browser" : "Synchronisez avec votre navigateur",
    "Select folder" : "Sélectionner un dossier",
    "Enter folder title" : "Saisissez le nom du dossier",
    "Shared by {user}" : "Partagé par l'{user}",
    "Rename folder" : "Renommer le dossier",
    "Move folder" : "Déplacer le dossier",
    "Delete folder" : "Supprimer le dossier",
    "Do you really want to delete this folder?" : "Voulez-vous vraiment supprimer ce dossier?",
    "Choose folder" : "Choisir le dossier",
    "Submit" : "Envoyer",
    "Cancel" : "Annuler",
    "Deleting bookmarks" : "Suppression des favoris",
    "Deleting selection" : "Suppression de la sélection",
    "Importing bookmarks" : "Import des favoris",
    "Moving selection" : "Déplacement de la sélection",
    "Adding selection to folders" : "Ajout de la sélection aux dossiers",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Déplacement de %n dossier et de certains signets","Déplacement de %n dossiers et de certains signets","Déplacement de %n dossiers et de certains signets"],
    "_Moving %n folder_::_Moving %n folders_" : ["Déplacement de %n dossier","Déplacement de %n dossiers","Déplacement de %n dossiers"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Déplacement de %n favori","Déplacement de %n favoris","Déplacement de %n favoris"],
    "All bookmarks" : "Tous les favoris",
    "Recent" : "Récent",
    "Shared with you" : "Partagés avec vous",
    "Files" : "Fichiers",
    "Duplicates" : "Duplicates",
    "Broken links" : "Liens brisés",
    "New tag" : "Nouvelle étiquette",
    "Search tags" : "Rechercher des étiquettes",
    "Untagged" : "Sans étiquette",
    "{used} bookmarks of {available} available" : "{used} favoris sur {available} disponibles",
    "No bookmarked files" : "Aucun fichier en favori",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les favoris vers des fichiers comme des photos ou des PDF seront automatiquement enregistrés dans vos fichiers Nextcloud, pour que vous puissiez y accéder même quand le lien est hors connexion.",
    "No broken links" : "Aucun lien brisé",
    "No shared folders" : "Aucun dossier partagé",
    "No duplicated bookmarks" : "Aucun favori en double",
    "No bookmarks here" : "Aucun favori ici",
    "Import" : "Importer",
    "Export" : "Exporter",
    "Archive path" : "Archiver le chemin d'accès",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Entrer le chemin d’accès d’un dossier dans vos fichiers où les fichiers favoris doivent être stockés.",
    "Backups" : "Sauvegardes",
    "Client apps" : "Applications clientes",
    "Also check out the collection of client apps that integrate with this app: " : "Découvrez également une gamme d'applications client qui s'intègrent à cette application : ",
    "Install web app on device" : "Installer l’application web sur l’appareil",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Vous pouvez installer cette application sur l’écran d’accueil de votre téléphone pour accéder rapidement à vos favoris. Vous pourrez facilement retirer cette application de votre écran si elle ne vous plaît pas.",
    "Install on home screen" : "Installer sur l'écran d'accueil",
    "Bookmarklet" : "Favelets",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Faites glisser ce lien vers les favoris de votre navigateur et cliquez dessus pour ajouter rapidement un favori à une page Web.",
    "Add to {instanceName}" : "Ajouter à {instanceName}",
    "Please select \"Add to home screen\" in your browser menu" : "Veuillez sélectionner \"Ajouter à l'écran d'accueil\" dans le menu de votre navigateur",
    "Title" : "Titre",
    "Link" : "Lien",
    "Untitled folder" : "Dossier sans titre",
    "Root folder" : "Dossier racine",
    "Tags" : "Étiquettes",
    "Select tags and create new ones" : "Sélectionner des étiquettes ou en créer de nouvelles",
    "Notes" : "Notes",
    "Notes for this bookmark …" : "Notes pour ce favori ...",
    "Archived file" : "Fichier archivé",
    "Open file" : "Ouvrir le fichier",
    "Open file location" : "Ouvrir l’emplacement du fichier",
    "Projects" : "Projets",
    "Created {time} ago" : "Créé il y a {time}",
    "Created on {date}" : "Créé le {date}",
    "Owner" : "Propriétaire",
    "Sharing" : "Partagé",
    "Select a user or group" : "Sélectionnez un utilisateur ou un groupe",
    "Share link" : "Lien de partage",
    "Reading allowed" : "Lecture autorisée",
    "Copy link" : "Copier le lien",
    "Copy RSS feed" : "Copier le flux RSS",
    "Delete link" : "Supprimer le lien",
    "Create public link" : "Créer une lien de partage public",
    "Resharing allowed" : "Repartage autorisé",
    "Editing allowed" : "Modification autorisée",
    "Allow editing" : "Autoriser la modification",
    "Allow resharing" : "Autoriser le repartage",
    "Remove share" : "Supprimer le partage",
    "Link copied" : "Lien copié",
    "Privacy" : "Vie privée",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bookmarks tentera d'accéder aux pages Web que vous enregistrez pour ajouter automatiquement des informations à leur sujet.",
    "Enable accessing and collecting information from the web pages you add" : "Activer l'accès et la collecte d'informations à partir des pages Web que vous enregistrez",
    "Performance" : "Performance",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Dans une installation avec un grand nombre d'utilisateurs, il peut être utile de restreindre le nombre de favoris par compte.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nombre maximum de signets autorisés par compte (0 pour aucune limite ; par défaut, aucune limite)",
    "Previews" : "Prévisualisations",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Afin d'afficher de vrais captures d'écrans de vos sites favoris, Favoris peut utiliser des services tiers pour générer ces aperçus",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Vous pouvez vous inscrire gratuitement sur screeenly.com ou configurer votre propre serveur.",
    "Screeenly API URL" : "URL API Screenly",
    "Screeenly API key" : "Clé API Screenly",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL de l'API Webshot",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Clé API de ScreenshotMachine",
    "Pageres CLI" : "Pageres CLI",
    "Failed to save settings" : "Echec de la sauvegarde des paramètres",
    "Failed to load settings" : "Echec du chargement des paramètres",
    "This URL is already bookmarked! Overwrite?" : "Cette URL est déjà dans les favoris ! Remplacer ?",
    "Enter bookmark title" : "Saisissez le nom du favori",
    "Enter bookmark URL" : "Saisissez l'url du favori",
    "Folder" : "Dossier",
    "Root Folder" : "Dossier racine",
    "Save" : "Enregistrer",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "L’accès au réseau est désactivé par défaut. Rendez-vous dans les paramètres administrateur de cette application pour autoriser le téléchargement de prévisualisations et de favicons.",
    "Link to a bookmark folder" : "Lien vers un dossier de favoris",
    "Failed to count unavailable bookmarks" : "Impossible de compter les favoris indisponibles",
    "Failed to count archived bookmarks" : "Impossible de compter les favoris archivés",
    "Failed to count duplicated bookmarks" : "Impossible de compter les favoris dupliqués",
    "Failed to load bookmark" : "Impossible de charger les favoris",
    "Failed to find existing bookmark" : "Impossible de trouver un signet existant",
    "Failed to create bookmark" : "Echec de la création du favori",
    "Failed to save bookmark" : "Echec de la sauvegarde du favori",
    "Failed to move bookmark" : "Impossible de déplacer le favori",
    "Failed to copy bookmark" : "Impossible de copier le favori",
    "Failed to delete bookmark" : "Impossible de supprimer le favori",
    "Failed to rename tag" : "Impossible de renommer le tag",
    "Failed to load tags" : "Impossible de charger les étiquettes",
    "Failed to load folders" : "Impossible de charger les dossiers",
    "Failed to delete folder" : "Impossible de supprimer le dossier",
    "Failed to create folder" : "Impossible de créer le dossier",
    "Failed to fetch bookmarks." : "Impossible de récupérer les signets.",
    "Failed to change setting" : "Impossible de modifier les paramètres",
    "Failed to load setting {key}" : "Échec du chargement du paramètre {key}",
    "Failed to update share {shareId}" : "Impossible de mettre à jour le partage {shareId}",
    "Failed to delete share {shareId}" : "Impossible de supprimer le partage {shareId}",
    "No links found in this message" : "Aucun lien trouvé dans ce message",
    "Bookmarks feed" : "Flux de suivi"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
